<?xml version="1.0" ?><!DOCTYPE TS><TS language="it_IT" version="2.0">
<context>
    <name>Dialog</name>
    <message>
        <source>Leave</source>
        <translation>Esci</translation>
    </message>
    <message>
        <source>What do you want the computer to do?</source>
        <translation>Cosa vuoi fare?</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Termina sessione</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Riavvia</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Spegni</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Sospendi</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Iberna</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
</TS>